package com.shzg.project.worn.mapper;

import java.util.List;
import com.shzg.project.worn.domain.MqttSensorCommand;

/**
 * 指令管理Mapper接口
 * 
 * @author shzg
 * @date 2026-04-01
 */
public interface MqttSensorCommandMapper 
{
    /**
     * 查询指令管理
     * 
     * @param id 指令管理主键
     * @return 指令管理
     */
    public MqttSensorCommand selectMqttSensorCommandById(Long id);

    /**
     * 查询指令管理列表
     * 
     * @param mqttSensorCommand 指令管理
     * @return 指令管理集合
     */
    public List<MqttSensorCommand> selectMqttSensorCommandList(MqttSensorCommand mqttSensorCommand);

    /**
     * 新增指令管理
     * 
     * @param mqttSensorCommand 指令管理
     * @return 结果
     */
    public int insertMqttSensorCommand(MqttSensorCommand mqttSensorCommand);

    /**
     * 修改指令管理
     * 
     * @param mqttSensorCommand 指令管理
     * @return 结果
     */
    public int updateMqttSensorCommand(MqttSensorCommand mqttSensorCommand);

    /**
     * 删除指令管理
     * 
     * @param id 指令管理主键
     * @return 结果
     */
    public int deleteMqttSensorCommandById(Long id);

    /**
     * 批量删除指令管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMqttSensorCommandByIds(Long[] ids);
}
