package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.MqttSensorCommand;
import com.shzg.project.worn.service.IMqttSensorCommandService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 指令管理Controller
 * 
 * @author shzg
 * @date 2026-04-01
 */
@RestController
@RequestMapping("/worn/mqttCommand")
public class MqttSensorCommandController extends BaseController
{
    @Autowired
    private IMqttSensorCommandService mqttSensorCommandService;

    /**
     * 查询指令管理列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttCommand:list')")
    @GetMapping("/list")
    public TableDataInfo list(MqttSensorCommand mqttSensorCommand)
    {
        startPage();
        List<MqttSensorCommand> list = mqttSensorCommandService.selectMqttSensorCommandList(mqttSensorCommand);
        return getDataTable(list);
    }

    /**
     * 导出指令管理列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttCommand:export')")
    @Log(title = "指令管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MqttSensorCommand mqttSensorCommand)
    {
        List<MqttSensorCommand> list = mqttSensorCommandService.selectMqttSensorCommandList(mqttSensorCommand);
        ExcelUtil<MqttSensorCommand> util = new ExcelUtil<MqttSensorCommand>(MqttSensorCommand.class);
        util.exportExcel(response, list, "指令管理数据");
    }

    /**
     * 获取指令管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttCommand:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mqttSensorCommandService.selectMqttSensorCommandById(id));
    }

    /**
     * 新增指令管理
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttCommand:add')")
    @Log(title = "指令管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MqttSensorCommand mqttSensorCommand)
    {
        return toAjax(mqttSensorCommandService.insertMqttSensorCommand(mqttSensorCommand));
    }

    /**
     * 修改指令管理
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttCommand:edit')")
    @Log(title = "指令管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MqttSensorCommand mqttSensorCommand)
    {
        return toAjax(mqttSensorCommandService.updateMqttSensorCommand(mqttSensorCommand));
    }

    /**
     * 删除指令管理
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttCommand:remove')")
    @Log(title = "指令管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mqttSensorCommandService.deleteMqttSensorCommandByIds(ids));
    }
}
